
; NAME :    
;           scatAngleDeg
; PURPOSE :
;           Function to compute scattering angle for a given sun-satellite geometry
;    
; CALLING :
;           scat_ang = scatAngleDeg, sol, view, azm
;           sol, view, azm can be scalars or vectors of the same length
;                        
; INPUTS  :
;           sol    = Solar Angle in degrees
;           view   = View Angle in degrees
;           azm    = Azimuth Angle in degrees
; OUTPUT  :
;           Scattering Angle
;           DIMS of sol, view, azm angle vector (similar dims for three angles)
;              
; HISTORY:
; Written: Nandana Amarasinghe, SSAI @ NASA/GSFC, 2017.
;

FUNCTION scatAngleDeg, solarAng, viewAng, relAzm


 ; torad = !PI / 180.d0

  solarmu = COS(solarAng * !dtor)
  viewmu = COS(viewAng * !dtor)

  scatAngle= -solarmu*viewmu + SQRT( ( 1.- solarmu^2 )*( 1.- viewmu^2 ) )*COS( relAzm * !dtor )
 ; if(n_elements(scatangle) gt 1)then begin
  idx= where(scatAngle lt -1.0, ct)
  if(ct gt 0)then scatAngle[idx]=-1.0
  idx= where(scatAngle gt 1.0, ct)
    if(ct gt 0)then scatAngle[idx]=1.0
  
   scatAngle = ACOS(scatAngle) * !radeg
  
  RETURN, scatAngle
 
 end
