#! /usr/bin/env python3.5

#;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
#
## Driver to calculate the Total reflectance (MS + SS) from C6 MODIS LUTS over land surface
#
#
#  Modified:   5 June 2017
#
#  Author:
#
#   Nandana Amarasinghe
#
#  Input Parameters:   None
#  Output : HDF file with liquid and ice reflectance data.
#;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



import pprint
import numpy as np
from pyhdf.SD import SD, SDC
from interpolateLUTSFLIPPED_multi_3pt5 import *
from time import time
from datetime import datetime, date, time
import sys
import timeit


## LUT Information;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
LUTDIR = '/Users/nandana/MODIS_ACOL_LUTS/'#path to where the library folder "MODIS_C6_LUTS" is located

  
phaseFileName       = LUTDIR + 'MODIS_C6_LUTS/modis_water/IceAndWaterPhaseFunctionData_2013.hdf'

lambWaterLUTName    = LUTDIR + 'MODIS_C6_LUTS/modis_water/reflectance_water_library.hdf'
  
lambIceLUTName      = LUTDIR + 'MODIS_C6_LUTS/modis_ice/reflectance_ice_library.hdf'
  
#END LUT Information;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


nphi = 37
numu = 28
nsolar = 33

deltaphi=5.0
relazm = np.linspace(0.,180.,nphi)
zviewmu=np.zeros(numu)
solarmu =np.zeros(nsolar)
zviewmu[0:8] = np.linspace(0.40,0.75,8)
zviewmu[8:28]= np.linspace(0.7625,1.0,20)
solarmu[0:13]= np.linspace(0.15,0.75,13)
solarmu[13:33]=np.linspace(0.7625,1.0,20)

solarangvec = np.arccos(solarmu) * 180.0/np.pi
viewangvec = np.arccos(zviewmu) * 180.0/np.pi
print('Given below are the 37 azimuth, 33 solar, and 28 view angles for LUTs')
print('Pick/choose the angular geometry from these angles')
print(' ')
print('%6s %10s %10s %10s' %( 'index','azimuth', 'solar','view'))
print(' ')
for i in range(nphi):
    if(i < 28):print('%4d %9.0f %13.2f' '%12.2f'%(i+1,relazm[i], solarangvec[i],viewangvec[i]))
    if(i >= 28 and i < 33):print('%4d %9.0f %13.2f'%(i+1,relazm[i], solarangvec[i]))
    if(i >= 33):print('%4d %9.0f'%(i+1,relazm[i]))

iazm=0
isol=0
iumu=0
print(' ')
print('Pick the indices of the angle combination to run.')
print('(Example output was created with all angles = 60, i.e., iazm=13, isol=8, iview=3 & surfalb=0.0)')
iazm=int(input('Enter index for the rel azimuth: '))
azmang=relazm[iazm-1]  #to get the python indexing
print('Relative Azimuth = %5.1f degrees'%azmang)
isol=int(input('Enter index for the solar zenith: '))
solang = np.arccos(solarmu[isol-1]) * 180.0/np.pi
print('Solar Zenith = %6.2f degrees'%solang)
iumu=int(input('Enter index for the zensor zenith: '))
viewang = np.arccos(zviewmu[iumu-1]) * 180.0/np.pi
print('Sensor Zenith/View = %6.2f degrees'%viewang)

surfalb=float(input('Now enter a value for the surface albedo: '))
iag = int(np.floor(surfalb))
fag = int(100*(surfalb - iag))

dt = datetime.now()
tt=dt.timetuple()
timestamp = '{:4d}{:03d}{:02d}{:02d}{:02d}'.format(tt[0],tt[7],tt[3],tt[4],tt[5])
outFile = LUTDIR +'MODIS_C6_LUTS/OUTPUT/land_PY_C6_reflectance_sol_{:02d}_view_{:02d}_relazm_{:02d}_ag_{:1d}pt{:02d}_{:s}.hdf'.format(isol,iumu,iazm,iag,fag,timestamp)


pfdatalamb = getPhaseFunctionData(phaseFileName)
lutdatlamb,sscdatlamb = readLambOrOceanLUTData(lambWaterLUTName,solang, viewang, azmang,LAND='LAND')

reflW=getReflForGivenSurfAlbedo(pfdatalamb,lutdatlamb,sscdatlamb,solang, viewang, azmang,surfalb,'LIQUID')
reflW=np.squeeze(reflW)
#print(reflW.shape)
rew = np.squeeze(sscdatlamb['RE'])
tau = np.squeeze(sscdatlamb['COT'])
wavelength = np.squeeze(sscdatlamb['WVL'])
lutdatlamb,sscdatlamb = readLambOrOceanLUTData(lambIceLUTName,solang, viewang, azmang,LAND='LAND')
reflI=getReflForGivenSurfAlbedo(pfdatalamb,lutdatlamb,sscdatlamb,solang, viewang, azmang,surfalb,'ICE')
reflI=np.squeeze(reflI)

rei = np.squeeze(sscdatlamb['RE'])
angs=[solang, viewang, azmang]
print(outFile)
istatus=createHDFFile(outFile,reflW,reflI,angs,surfalb,rew,rei,tau,wavelength,LAND='LAND')



